==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/pl/rosterchanger.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>AddContactDialog</name>
    <message>
        <source>Please, authorize me to your presence.</source>
        <translation>Proszę, autoryzuj mnie.</translation>
    </message>
    <message>
        <source>Add contact - %1</source>
        <translation>Dodaj kontakt - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Czat</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Otwórz okno czatu</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadomość</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Wyślij wiadomość</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Pokaż vCard</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Resolve nick name</source>
        <translation>Pobież nick</translation>
    </message>
    <message>
        <source>Contact &lt;b&gt;%1&lt;/b&gt; already exists.</source>
        <translation>Kontakt &lt;b&gt;%1&lt;/b&gt; już istnieje.</translation>
    </message>
    <message>
        <source>* nested group delimiter - &apos;%1&apos;</source>
        <translation>* separator grup zagnieżdżonych - %1</translation>
    </message>
    <message>
        <source>Can&apos;t add contact &apos;&lt;b&gt;%1&lt;/b&gt;&apos; because it is not a valid Jabber ID</source>
        <translation>Nie można dodać kontaktu &apos;&lt;b&gt;%1&lt;/b&gt;&apos; z powodu błędnego JID</translation>
    </message>
</context>
<context>
    <name>AddContactDialogClass</name>
    <message>
        <source>Nick:</source>
        <translation>Nick:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupa:</translation>
    </message>
    <message>
        <source>Contact:</source>
        <translation>Kontakt:</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Subskrypcja</translation>
    </message>
    <message>
        <source>Subscribe to contact presence</source>
        <translation>Wyślij prośbę o autoryzację</translation>
    </message>
</context>
<context>
    <name>RosterChanger</name>
    <message>
        <source>Subscription requests</source>
        <translation>Żądania autoryzacji</translation>
    </message>
    <message>
        <source>%1 wants to subscribe to your presence.</source>
        <translation>%1 chce subskrybować twój status.</translation>
    </message>
    <message>
        <source>%1 unsubscribed from your presence.</source>
        <translation>%1 anulował sybskrypcję twojego statusu.</translation>
    </message>
    <message>
        <source>You are now unsubscribed from %1 presence.</source>
        <translation>%1 anulował twoją autoryzację do otrzymywania jego statusu.</translation>
    </message>
    <message>
        <source>This group</source>
        <translation>Do tej grupy</translation>
    </message>
    <message>
        <source>Create new...</source>
        <translation>Utwórz nową...</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Do pnia</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Autoryzacja</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Request</source>
        <translation>Poproś</translation>
    </message>
    <message>
        <source>Copy contact</source>
        <translation>Kopiuj kontakt</translation>
    </message>
    <message>
        <source>Move contact</source>
        <translation>Przenieś kontakt</translation>
    </message>
    <message>
        <source>Copy group</source>
        <translation>Kopiuj grupę</translation>
    </message>
    <message>
        <source>Move group</source>
        <translation>Przenieś grupę</translation>
    </message>
    <message>
        <source>Refuse</source>
        <translation>Odmów</translation>
    </message>
    <message>
        <source>Copy to group</source>
        <translation>Kopiuj do grupy</translation>
    </message>
    <message>
        <source>Move to group</source>
        <translation>Przenieś do grupy</translation>
    </message>
    <message>
        <source>Remove from group</source>
        <translation>Usuń z grupy</translation>
    </message>
    <message>
        <source>Remove from roster</source>
        <translation>Usuń z rostera</translation>
    </message>
    <message>
        <source>Remove group</source>
        <translation>Usun grupę</translation>
    </message>
    <message>
        <source>Remove contacts</source>
        <translation>Usuń kontakty</translation>
    </message>
    <message>
        <source>Subscription message from %1</source>
        <translation>Wiadomość autoryzacji od %1</translation>
    </message>
    <message>
        <source>Subscription message</source>
        <translation>Wiadomość autoryzacji</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Zmień nazwę kontaktu</translation>
    </message>
    <message>
        <source>Enter name for: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Wpisz nazwę dla: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create new group</source>
        <translation>Utwórz nową grupę</translation>
    </message>
    <message>
        <source>Enter group name:</source>
        <translation>Wpisz nazwę grupy:</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Usuń kontakt</translation>
    </message>
    <message>
        <source>You are assured that wish to remove a contact &lt;b&gt;%1&lt;/b&gt; from roster?</source>
        <translation>Jesteś pewien, że chcesz usunąć kontakt &lt;b&gt;%1&lt;/b&gt; z rostera?</translation>
    </message>
    <message>
        <source>Rename group</source>
        <translation>Zmień nazwę grupy</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Wprowadź nową nazwę grupy:</translation>
    </message>
    <message>
        <source>You are assured that wish to remove %1 contact(s) from roster?</source>
        <translation>Jesteś pewien, że chcesz usunąć %1 kontakt(y/ów) z rostera?</translation>
    </message>
    <message>
        <source>You are now subscribed for %1 presence.</source>
        <translation>%1 autoryzował ciebie do otrzymywania jego statusu.</translation>
    </message>
    <message>
        <source>Add contact</source>
        <translation>Dodaj kontakt</translation>
    </message>
    <message>
        <source>Subscribe contact</source>
        <translation>Autoryzuj kontakt</translation>
    </message>
    <message>
        <source>Unsubscribe contact</source>
        <translation>Cofnij autoryzację</translation>
    </message>
    <message>
        <source>Subscribe for contact presence</source>
        <translation>subskrybuj otrzymywanie statusu kontaktu</translation>
    </message>
    <message>
        <source>You are assured that wish to subscribe for a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Czy na pewno chcesz subskrybować status kontaktu &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Unsubscribe from contact presence</source>
        <translation>Zaprzestań subskrypcji statusu kontaktu</translation>
    </message>
    <message>
        <source>You are assured that wish to unsubscribe from a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Jesteś pewien, że chcesz zaprzestać subskrypcji statusu kontaktu &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Roster Editor</source>
        <translation>Edytor rostera</translation>
    </message>
    <message>
        <source>Allows to edit roster</source>
        <translation>Umożliwia edycję rostera</translation>
    </message>
    <message>
        <source>Auto accept subscription requests</source>
        <translation>Akceptuj automatycznie prośby o autoryzację</translation>
    </message>
    <message>
        <source>Auto unsubscribe contacts</source>
        <translation>Automatycznie cofaj autoryzację</translation>
    </message>
    <message>
        <source>Ins</source>
        <comment>Add contact</comment>
        <translation>Ins</translation>
    </message>
    <message>
        <source>Rename contact/group</source>
        <translation>Zmień nazwę kontaktu/grupy</translation>
    </message>
    <message>
        <source>F2</source>
        <comment>Rename contact/group</comment>
        <translation>F2</translation>
    </message>
    <message>
        <source>Remove contact/group from group</source>
        <translation>Usuń kontakt/grupę z grupy</translation>
    </message>
    <message>
        <source>Del</source>
        <comment>Remove contact/group from group</comment>
        <translation>Del</translation>
    </message>
    <message>
        <source>Remove contact/group from roster</source>
        <translation>Usuń kontakt/grupę z listy kontaktów</translation>
    </message>
    <message>
        <source>Shift+Del</source>
        <comment>Remove contact/group from roster</comment>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <source>Add contact...</source>
        <translation>Dodaj kontakt...</translation>
    </message>
    <message>
        <source>Blank Group</source>
        <translation>Pusta grupa</translation>
    </message>
    <message>
        <source>Roster management</source>
        <translation>Zarządzanie listą kontaktów</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialog</name>
    <message>
        <source>Subscription request - %1</source>
        <translation>Prośba o autoryzację - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Czat</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Otwórz okno czatu</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadomość</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Wyślij wiadomość</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Pokaż vCard</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialogClass</name>
    <message>
        <source>Add user to contact list</source>
        <translation>Dodaj użytkownika do listy kontaktów</translation>
    </message>
    <message>
        <source>Authorize presence subscription</source>
        <translation>Autoryzuj</translation>
    </message>
    <message>
        <source>Remove presence subscription</source>
        <translation>Cofnij autoryzację</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/pl/rosterchanger.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>AddContactDialog</name>
    <message>
        <source>Please, authorize me to your presence.</source>
        <translation>Proszę, autoryzuj mnie.</translation>
    </message>
    <message>
        <source>Add contact - %1</source>
        <translation>Dodaj kontakt - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Czat</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Otwórz okno czatu</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadomość</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Wyślij wiadomość</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Pokaż vCard</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Resolve nick name</source>
        <translation>Pobież nick</translation>
    </message>
    <message>
        <source>Contact &lt;b&gt;%1&lt;/b&gt; already exists.</source>
        <translation>Kontakt &lt;b&gt;%1&lt;/b&gt; już istnieje.</translation>
    </message>
    <message>
        <source>* nested group delimiter - &apos;%1&apos;</source>
        <translation>* separator grup zagnieżdżonych - %1</translation>
    </message>
    <message>
        <source>Can&apos;t add contact &apos;&lt;b&gt;%1&lt;/b&gt;&apos; because it is not a valid Jabber ID</source>
        <translation>Nie można dodać kontaktu &apos;&lt;b&gt;%1&lt;/b&gt;&apos; z powodu błędnego JID</translation>
    </message>
</context>
<context>
    <name>AddContactDialogClass</name>
    <message>
        <source>Nick:</source>
        <translation>Nick:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupa:</translation>
    </message>
    <message>
        <source>Contact:</source>
        <translation>Kontakt:</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Subskrypcja</translation>
    </message>
    <message>
        <source>Subscribe to contact presence</source>
        <translation>Wyślij prośbę o autoryzację</translation>
    </message>
</context>
<context>
    <name>RosterChanger</name>
    <message>
        <source>%1 wants to subscribe to your presence.</source>
        <translation>%1 chce subskrybować twój status.</translation>
    </message>
    <message>
        <source>%1 unsubscribed from your presence.</source>
        <translation>%1 anulował sybskrypcję twojego statusu.</translation>
    </message>
    <message>
        <source>You are now unsubscribed from %1 presence.</source>
        <translation>%1 anulował twoją autoryzację do otrzymywania jego statusu.</translation>
    </message>
    <message>
        <source>This group</source>
        <translation>Do tej grupy</translation>
    </message>
    <message>
        <source>Create new...</source>
        <translation>Utwórz nową...</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Do pnia</translation>
    </message>
    <message>
        <source>Subscription</source>
        <translation>Autoryzacja</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Request</source>
        <translation>Poproś</translation>
    </message>
    <message>
        <source>Copy contact</source>
        <translation>Kopiuj kontakt</translation>
    </message>
    <message>
        <source>Move contact</source>
        <translation>Przenieś kontakt</translation>
    </message>
    <message>
        <source>Copy group</source>
        <translation>Kopiuj grupę</translation>
    </message>
    <message>
        <source>Move group</source>
        <translation>Przenieś grupę</translation>
    </message>
    <message>
        <source>Refuse</source>
        <translation>Odmów</translation>
    </message>
    <message>
        <source>Copy to group</source>
        <translation>Kopiuj do grupy</translation>
    </message>
    <message>
        <source>Move to group</source>
        <translation>Przenieś do grupy</translation>
    </message>
    <message>
        <source>Remove from group</source>
        <translation>Usuń z grupy</translation>
    </message>
    <message>
        <source>Remove from roster</source>
        <translation>Usuń z rostera</translation>
    </message>
    <message>
        <source>Remove group</source>
        <translation>Usun grupę</translation>
    </message>
    <message>
        <source>Remove contacts</source>
        <translation>Usuń kontakty</translation>
    </message>
    <message>
        <source>Subscription message from %1</source>
        <translation>Wiadomość autoryzacji od %1</translation>
    </message>
    <message>
        <source>Subscription message</source>
        <translation>Wiadomość autoryzacji</translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation>Zmień nazwę kontaktu</translation>
    </message>
    <message>
        <source>Enter name for: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Wpisz nazwę dla: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Create new group</source>
        <translation>Utwórz nową grupę</translation>
    </message>
    <message>
        <source>Enter group name:</source>
        <translation>Wpisz nazwę grupy:</translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation>Usuń kontakt</translation>
    </message>
    <message>
        <source>You are assured that wish to remove a contact &lt;b&gt;%1&lt;/b&gt; from roster?</source>
        <translation>Jesteś pewien, że chcesz usunąć kontakt &lt;b&gt;%1&lt;/b&gt; z rostera?</translation>
    </message>
    <message>
        <source>Rename group</source>
        <translation>Zmień nazwę grupy</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Wprowadź nową nazwę grupy:</translation>
    </message>
    <message>
        <source>You are now subscribed for %1 presence.</source>
        <translation>%1 autoryzował ciebie do otrzymywania jego statusu.</translation>
    </message>
    <message>
        <source>Add contact</source>
        <translation>Dodaj kontakt</translation>
    </message>
    <message>
        <source>Subscribe contact</source>
        <translation>Autoryzuj kontakt</translation>
    </message>
    <message>
        <source>Unsubscribe contact</source>
        <translation>Cofnij autoryzację</translation>
    </message>
    <message>
        <source>Subscribe for contact presence</source>
        <translation>subskrybuj otrzymywanie statusu kontaktu</translation>
    </message>
    <message>
        <source>You are assured that wish to subscribe for a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Czy na pewno chcesz subskrybować status kontaktu &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Unsubscribe from contact presence</source>
        <translation>Zaprzestań subskrypcji statusu kontaktu</translation>
    </message>
    <message>
        <source>You are assured that wish to unsubscribe from a contact &lt;b&gt;%1&lt;/b&gt; presence?</source>
        <translation>Jesteś pewien, że chcesz zaprzestać subskrypcji statusu kontaktu &lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Roster Editor</source>
        <translation>Edytor rostera</translation>
    </message>
    <message>
        <source>Allows to edit roster</source>
        <translation>Umożliwia edycję rostera</translation>
    </message>
    <message>
        <source>Auto accept subscription requests</source>
        <translation>Akceptuj automatycznie prośby o autoryzację</translation>
    </message>
    <message>
        <source>Auto unsubscribe contacts</source>
        <translation>Automatycznie cofaj autoryzację</translation>
    </message>
    <message>
        <source>Ins</source>
        <comment>Add contact</comment>
        <translation>Ins</translation>
    </message>
    <message>
        <source>Rename contact/group</source>
        <translation>Zmień nazwę kontaktu/grupy</translation>
    </message>
    <message>
        <source>F2</source>
        <comment>Rename contact/group</comment>
        <translation>F2</translation>
    </message>
    <message>
        <source>Remove contact/group from group</source>
        <translation>Usuń kontakt/grupę z grupy</translation>
    </message>
    <message>
        <source>Del</source>
        <comment>Remove contact/group from group</comment>
        <translation>Del</translation>
    </message>
    <message>
        <source>Remove contact/group from roster</source>
        <translation>Usuń kontakt/grupę z listy kontaktów</translation>
    </message>
    <message>
        <source>Shift+Del</source>
        <comment>Remove contact/group from roster</comment>
        <translation>Shift+Del</translation>
    </message>
    <message>
        <source>Add contact...</source>
        <translation>Dodaj kontakt...</translation>
    </message>
    <message>
        <source>Blank Group</source>
        <translation>Pusta grupa</translation>
    </message>
    <message>
        <source>When receiving authorization request</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>You are assured that wish to remove &lt;b&gt;%n contact(s)&lt;/b&gt; from roster?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SubscriptionDialog</name>
    <message>
        <source>Subscription request - %1</source>
        <translation>Prośba o autoryzację - %1</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Czat</translation>
    </message>
    <message>
        <source>Open chat window</source>
        <translation>Otwórz okno czatu</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Wiadomość</translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Wyślij wiadomość</translation>
    </message>
    <message>
        <source>VCard</source>
        <translation>vCard</translation>
    </message>
    <message>
        <source>Show VCard</source>
        <translation>Pokaż vCard</translation>
    </message>
</context>
<context>
    <name>SubscriptionDialogClass</name>
    <message>
        <source>Add user to contact list</source>
        <translation>Dodaj użytkownika do listy kontaktów</translation>
    </message>
    <message>
        <source>Authorize presence subscription</source>
        <translation>Autoryzuj</translation>
    </message>
    <message>
        <source>Remove presence subscription</source>
        <translation>Cofnij autoryzację</translation>
    </message>
</context>
</TS>
